import { useTranslation } from 'react-i18next'

import { styled } from '@mui/system'
import Box from '@mui/material/Box'
import AccountBoxOutlinedIcon from '@mui/icons-material/AccountBoxOutlined'

import { HrefButton } from 'components/button'
import { Button } from '@mui/material'

const StyledParagraph = styled('p')({
  fontSize: '1rem',
})

const StyledBox = styled(Box)({
  borderStyle: 'solid',
  borderColor: 'black',
  borderWidth: '2px',
  borderRadius: '11px',
})

interface LoginBoxProps {
  header: string
  info: string
  manual?: boolean
  large?: boolean
}

const LoginBox = ({ header, info, manual, large }: LoginBoxProps) => {
  const { t } = useTranslation('login')
  return (
    <StyledBox
      sx={{
        width: large ? '48rem' : '24rem',
        height: '18rem',
        marginBottom: { xs: '2rem', md: '0rem' },
      }}
    >
      <Box
        sx={{
          display: 'flex',
          flexDirection: 'column',
          margin: '2rem',
          height: '35%',
        }}
      >
        <Box sx={{ display: 'flex', alignItems: 'center' }}>
          <AccountBoxOutlinedIcon
            fontSize="inherit"
            sx={{
              marginRight: { xs: '0rem', md: '0.5rem' },
            }}
          />
          {header}
        </Box>
        <StyledParagraph>{info}</StyledParagraph>
      </Box>
      <Box
        sx={{
          display: 'flex',
          margin: '2rem',
          flexDirection: 'column',
          gap: '16px',
        }}
      >
        <HrefButton to="/oidc/authenticate/">
          <Box sx={{ margin: '0 2rem 0 2rem', textTransform: 'none' }}>
            {t('login')}
          </Box>
        </HrefButton>

        {manual && (
          <Button
            sx={{ textTransform: 'none', border: '2px solid' }}
            href="/guestregister/"
            color="secondary"
          >
            <Box sx={{ margin: '0 2rem 0 2rem' }}>{t('manual')}</Box>
          </Button>
        )}
      </Box>
    </StyledBox>
  )
}
LoginBox.defaultProps = { manual: false, large: false }
export default LoginBox
