import React, { useEffect, useState } from 'react'

import { UserContext } from 'contexts'

type UserProviderProps = {
  children: React.ReactNode
}

function UserProvider(props: UserProviderProps) {
  const { children } = props
  const [user, setUser] = useState({
    auth: false,
    auth_type: '',
    fetched: false,
    first_name: '',
    last_name: '',
    feide_id: '',
    person_id: '',
    sponsor_id: '',
    email: '',
    mobile_phone: '',
    fnr: '',
    passport: '',
    roles: [],
  })

  const getUserInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/userinfo/')
      const data = await response.json()

      if (response.ok) {
        setUser({
          auth: true,
          auth_type: data.auth_type,
          fetched: true,
          first_name: data.first_name,
          last_name: data.last_name,
          feide_id: data.feide_id,
          person_id: data.person_id,
          sponsor_id: data.sponsor_id,
          email: data.email,
          mobile_phone: data.mobile_phone,
          fnr: data.fnr,
          passport: data.passport,
          roles: data.roles,
        })
      } else {
        setUser({
          auth: false,
          auth_type: '',
          fetched: true,
          first_name: '',
          last_name: '',
          feide_id: '',
          person_id: '',
          sponsor_id: '',
          email: '',
          mobile_phone: '',
          fnr: '',
          passport: '',
          roles: [],
        })
      }
    } catch (error) {
      setUser({
        auth: false,
        auth_type: '',
        fetched: true,
        first_name: '',
        last_name: '',
        feide_id: '',
        person_id: '',
        sponsor_id: '',
        email: '',
        mobile_phone: '',
        fnr: '',
        passport: '',
        roles: [],
      })
    }
  }

  const fetchUserInfo = () => {
    if (!user.auth) {
      getUserInfo()
    }
  }

  useEffect(() => {
    if (!user.auth && !user.fetched) {
      getUserInfo()
    }
  }, [])

  const clearUserInfo = () => {
    setUser({
      auth: false,
      auth_type: '',
      fetched: false,
      first_name: '',
      last_name: '',
      feide_id: '',
      person_id: '',
      sponsor_id: '',
      email: '',
      mobile_phone: '',
      fnr: '',
      passport: '',
      roles: [],
    })
  }

  return (
    <UserContext.Provider value={{ user, fetchUserInfo, clearUserInfo }}>
      {children}
    </UserContext.Provider>
  )
}

export default UserProvider
