import React from 'react'
import { render } from '@testing-library/react'
import { ThemeProvider } from '@mui/material/styles'

import { defaultTheme } from 'themes'

// Providers used in test rendering
const AllTheProviders = ({ children }: any) => (
  <ThemeProvider theme={defaultTheme}> {children} </ThemeProvider>
)

// Custom testing-library/react renderer using our providers.
const customRender = (ui: React.ReactElement, options?: any) =>
  render(ui, { wrapper: AllTheProviders, ...options })

// re-export everything
export * from '@testing-library/react'

// override render method
export { customRender as render }

// The reason for this complex mock of react-i18next is to make the Trans-component work when running tests
jest.mock('react-i18next', (): object => {
  // Need to require React at this level as well to avoid getting an error
  // when running the tests saying that the module factory is not allowed
  // to reference out-of-scope variables
  // eslint-disable-next-line @typescript-eslint/no-shadow,global-require
  const React = require('react')

  const hasChildren = (node: any): boolean =>
    node && (node.children || (node.props && node.props.children))

  const getChildrenFromProps = (node: any): any =>
    node.props && node.props.children ? node.props.children : null

  const getChildren = (node: any): any =>
    node && node.children ? node.children : getChildrenFromProps(node)

  const renderNodes = (reactNodes: any): any => {
    if (typeof reactNodes === 'string') {
      return reactNodes
    }

    return Object.keys(reactNodes).map((key, i) => {
      const child = reactNodes[key]

      if (typeof child === 'string') {
        return child
      }

      if (hasChildren(child)) {
        const inner = renderNodes(getChildren(child))
        // eslint-disable-next-line react/no-array-index-key
        return React.cloneElement(child, { ...child.props, key: i }, inner)
      }

      const isElement = React.isValidElement(child)
      if (typeof child === 'object' && !isElement) {
        return Object.keys(child).reduce(
          (str, childKey) => `${str}${child[childKey]}`,
          ''
        )
      }

      return child
    })
  }

  const useMock: any = [(k: any) => k, {}]
  // Mock react-i18next module to return a translation that just returns the key
  useMock.t = (k: any) => k
  useMock.i18n = {
    // Return "en" as the selected language if the code asks for it
    language: 'en',
    changeLanguage: () => new Promise(() => {}),
  }

  return {
    withTranslation:
      () =>
      (Component: any): any =>
      (props: any): any =>
        <Component t={(k: any): any => k} {...props} />,
    Trans: ({ children }: any) => renderNodes(children),
    Translation: ({ children }: any) =>
      children((k: any): any => k, { i18n: {} }),
    useTranslation: () => useMock,
  }
})
