from rest_framework import serializers
from rest_framework.fields import IntegerField, SerializerMethodField

from greg.api.serializers.organizational_unit import OrganizationalUnitSerializer
from greg.models import Role, RoleType


class RoleSerializer(serializers.ModelSerializer):
    type = serializers.SlugRelatedField(
        queryset=RoleType.objects.all(), slug_field="identifier"
    )
    orgunit = OrganizationalUnitSerializer()

    class Meta:
        model = Role
        fields = [
            "id",
            "start_date",
            "end_date",
            "sponsor",
            "orgunit",
            "created",
            "updated",
            "type",
            "available_in_search",
        ]


class RoleWriteSerializer(RoleSerializer):
    """
    Serializer for use with GET.

    When doing GET we want the complete orgunit object, not just the id.
    """

    orgunit = IntegerField(source="orgunit_id")  # type: ignore


class SpecialRoleSerializer(serializers.ModelSerializer):
    name_nb = SerializerMethodField(source="type")
    name_en = SerializerMethodField(source="type")
    ou_nb = SerializerMethodField(source="orgunit")
    ou_en = SerializerMethodField(source="orgunit")
    max_days = SerializerMethodField(source="type")

    def get_name_nb(self, obj):
        return obj.type.name_nb

    def get_name_en(self, obj):
        return obj.type.name_en

    def get_ou_nb(self, obj):
        return obj.orgunit.name_nb

    def get_ou_en(self, obj):
        return obj.orgunit.name_en

    def get_max_days(self, obj):
        return obj.type.max_days

    class Meta:
        model = Role
        fields = [
            "id",
            "name_nb",
            "name_en",
            "ou_nb",
            "ou_en",
            "start_date",
            "end_date",
            "max_days",
        ]
