"""
Django settings for greg project.

Generated by 'django-admin startproject' using Django 3.2.5.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

from pathlib import Path
from typing import List

import structlog

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "django-insecure-3zzk=de$-7=)rcnvwfi=05x)84d#s572e8fdq9ewt4y1cg2jy-"

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS: List[str] = []


# Application definition

INSTALLED_APPS = [
    "whitenoise.runserver_nostatic",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "rest_framework",
    "rest_framework.authtoken",
    "reversion",
    "drf_spectacular",
    "django_extensions",
    "django_filters",
    "mozilla_django_oidc",
    "django_q",
    "greg",
    "gregui",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "whitenoise.middleware.WhiteNoiseMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "sesame.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "django_structlog.middlewares.RequestMiddleware",
    "gregsite.middleware.revision_user_middleware.RevisionUserMiddleware",
]

AUTHENTICATION_BACKENDS = [
    "django.contrib.auth.backends.ModelBackend",  # default
    "gregui.authentication.auth_backends.GregOIDCBackend",
    "sesame.backends.ModelBackend",  # link login
]

SESAME_MAX_AGE = 600  # lifetime of token in seconds
SESSION_COOKIE_AGE = 1800  # lifetime of session in seconds

CSRF_COOKIE_SAMESITE = "Lax"
SESSION_COOKIE_SAMESITE = "Lax"
CSRF_COOKIE_HTTPONLY = False
SESSION_COOKIE_HTTPONLY = False

REST_FRAMEWORK = {
    "DEFAULT_VERSIONING_CLASS": "rest_framework.versioning.NamespaceVersioning",
    "DEFAULT_VERSION": "v1",
    "ALLOWED_VERSIONS": ("v1", "gregui-v1"),
    "DEFAULT_AUTHENTICATION_CLASSES": (
        "rest_framework.authentication.TokenAuthentication",
        "rest_framework.authentication.SessionAuthentication",
    ),
    "DEFAULT_PERMISSION_CLASSES": ("rest_framework.permissions.IsAuthenticated",),
    "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema",
    # Rate limit settings of invite endpoint
    "DEFAULT_THROTTLE_CLASSES": [
        "rest_framework.throttling.AnonRateThrottle",
    ],
    "DEFAULT_THROTTLE_RATES": {
        "anon": "10/minute",
    },
}

SPECTACULAR_SETTINGS = {
    "TITLE": "Greg",
    "DESCRIPTION": "Guest REGistration",
    # 'VERSION': '1.0.0',
    "PREPROCESSING_HOOKS": ["greg.api.api_doc_preprocessing.custom_preprocessing_hook"],
}

ROOT_URLCONF = "gregsite.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

WSGI_APPLICATION = "gregsite.wsgi.application"


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": BASE_DIR / "db.sqlite3",
    }
}


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

# Override these in dev.py
OIDC_RP_CLIENT_ID = ""
OIDC_RP_CLIENT_SECRET = ""

OIDC_RP_SIGN_ALGO = "RS256"
OIDC_RP_SCOPES = "email openid userid userid-feide userid-nin profile iss "
OIDC_OP_JWKS_ENDPOINT = "https://auth.dataporten.no/openid/jwks"
OIDC_OP_AUTHORIZATION_ENDPOINT = "https://auth.dataporten.no/oauth/authorization"
OIDC_OP_TOKEN_ENDPOINT = "https://auth.dataporten.no/oauth/token"
OIDC_OP_USER_ENDPOINT = "https://auth.dataporten.no/openid/userinfo"
OIDC_OP_FEIDE_EXTENDED_USER_ENDPOINT = "https://api.dataporten.no/userinfo/v1/userinfo"

ALLOW_LOGOUT_GET_METHOD = True
OIDC_END_SESSION_ENDPOINT = "https://auth.dataporten.no/openid/endsession"
OIDC_OP_LOGOUT_URL_METHOD = "gregui.authentication.auth_backends.provider_logout"

# Change these later
LOGIN_REDIRECT_URL = "http://localhost:3000/"
LOGOUT_REDIRECT_URL = "http://localhost:3000/"

# Extra config needed since mozilla-django-oidc does not comply with point 2. and 3.
# https://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation
OIDC_OP_ISSUER = "https://auth.dataporten.no"
OIDC_TRUSTED_AUDIENCES = []

# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = "en-us"
TIME_ZONE = "UTC"
USE_I18N = True
USE_TZ = True
DATETIME_FORMAT = "c"

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = "/staticfiles/"
STATIC_ROOT = BASE_DIR / "static"

# STATICFILES_DIRS = [BASE_DIR / ".." / "frontend" / "build"]

# STATICFILES_STORAGE = "django.contrib.staticfiles.storage.ManifestStaticFilesStorage"
STATICFILES_STORAGE = "whitenoise.storage.CompressedManifestStaticFilesStorage"

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"


# Logging

# Log level for all loggers except Django
LOG_LEVEL = "INFO"
if DEBUG:
    LOG_LEVEL = "DEBUG"

# Override this to DEBUG locally for super verbose logging
DJANGO_LOG_LEVEL = "INFO"

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "json_formatter": {
            "()": structlog.stdlib.ProcessorFormatter,
            "processor": structlog.processors.JSONRenderer(),
        },
    },
    "handlers": {
        "console": {
            "class": "logging.StreamHandler",
            "formatter": "json_formatter",
        },
    },
    "loggers": {
        "django_structlog": {
            "handlers": ["console"],
            "level": DJANGO_LOG_LEVEL,
        },
        "gregui": {
            "handlers": ["console"],
            "level": LOG_LEVEL,
        },
        "greg": {
            "handlers": ["console"],
            "level": LOG_LEVEL,
        },
        "pika": {"handlers": ["console"], "level": "ERROR"},
    },
}

structlog.configure(
    processors=[
        structlog.stdlib.filter_by_level,
        structlog.processors.TimeStamper(fmt="iso"),
        structlog.stdlib.add_logger_name,
        structlog.stdlib.add_log_level,
        structlog.stdlib.PositionalArgumentsFormatter(),
        structlog.processors.StackInfoRenderer(),
        structlog.processors.format_exc_info,
        structlog.processors.UnicodeDecoder(),
        structlog.stdlib.ProcessorFormatter.wrap_for_formatter,
    ],
    context_class=structlog.threadlocal.wrap_dict(dict),
    logger_factory=structlog.stdlib.LoggerFactory(),
    wrapper_class=structlog.stdlib.BoundLogger,
    cache_logger_on_first_use=True,
)


NOTIFICATION_PUBLISHER = {
    "mq": {
        "connection": {
            "hostname": "localhost",
            "port": 5672,
            "virtual_host": "/",
            "username": "guest",
            "password": "guest",
            "tls_on": False,
            "server_name_indication": True,
        },
        "exchange": "test",
    },
    "poll_interval": 5,
}

INSTANCE_NAME = "local"
# i.e. 'prod', 'test', ...
ENVIRONMENT = "unknown"
INTERNAL_RK_PREFIX = "no.{instance}.greg".format(instance=INSTANCE_NAME)

FEIDE_SOURCE = "feide"


# Used by the OU import from orgreg to distinguish the OuIdentifiers from others
ORGREG_SOURCE = "orgreg"
ORGREG_NAME = "orgreg_id"

# Extra ids to be imported from orgreg, list of dict with source/type.
# [{"source": "sapuio", "type": "legacy_stedkode"}]
ORGREG_EXTRA_IDS = []

# Acronyms to be imported as identifiers from orgreg. List of acronym values, supported ones are: nob, nno, eng
# Example list: ["nob"]
ORGREG_ACRONYMS = []
